Skip to content

ThreadNetwork macOS xcode27.0 b2

Alex Soto edited this page Jun 23, 2026 · 1 revision

#ThreadNetwork.framework

diff -ruN /Applications/Xcode_27.0.0-beta.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/ThreadNetwork.framework/Headers/THClient.h /Applications/Xcode_27.0.0-beta2.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/ThreadNetwork.framework/Headers/THClient.h
--- /Applications/Xcode_27.0.0-beta.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/ThreadNetwork.framework/Headers/THClient.h	2026-05-23 01:34:00
+++ /Applications/Xcode_27.0.0-beta2.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk/System/Library/Frameworks/ThreadNetwork.framework/Headers/THClient.h	2026-06-13 10:07:41
@@ -237,11 +237,14 @@
 /// This method scans for Thread credential sharing capable Apple Border Routers, selects an eligible device, and requests to generate an ephemeral 9-digit code and start credential sharing mode.
 ///
 /// When you call this method, an alert appears asking for user permission to
-/// access credentials.
+/// access credentials. The one-time admin code is displayed internally via an alert;
+/// it is not returned to the caller.
 ///
-/// - Parameters:
-///   - completion: The completion handler the framework calls when the
-///     one-time admin code becomes available.
+////// - Parameters:
+///   - extendedPANID: The extended PAN identifier of the Thread network.
+///   - completion: The completion handler the framework calls after the user
+///     acknowledges the alert. The `error` parameter is nil on success, or
+///     non-nil if credential sharing mode could not be enabled.
 ///
 /// > Concurrency Note: You can call this method from synchronous code using a completion handler,
 /// > as shown on this page, or you can call it as an asynchronous method that has the
@@ -249,13 +252,13 @@
 /// >
 /// > ```swift
 /// > // Completion handler form:
-/// > func enableCredentialSharingMode(completionHandler: @escaping (String?, Error?) -> Void)
+/// > func enableCredentialSharingModeWithExtendedPANId(extendedPANId: Data, completion: @escaping (Error?) -> Void)
 /// >
 /// > // Async form:
 /// > func enableCredentialSharingMode() async throws -> String
 /// > ```
 /// > For information about concurrency and asynchronous code in Swift, see <doc://com.apple.documentation/documentation/swift/calling-objective-c-apis-asynchronously>.
-- (void)enableCredentialSharingMode:(void (^)(NSString * _Nullable adminCode, NSError * _Nullable error))completion API_AVAILABLE(ios(27.0));
+- (void)enableCredentialSharingModeWithExtendedPANId:(nonnull NSData*)xpanId completion:(void (^)(NSError * _Nullable error))completion API_AVAILABLE(ios(27.0)) NS_SWIFT_ASYNC_NAME(enableCredentialSharingModeWithExtendedPANId(extendedPANId:));
 @end
 
 NS_ASSUME_NONNULL_END
@@ -249,13 +252,13 @@
 /// >
-/// > // Async form:
-/// > func enableCredentialSharingMode() async throws -> String
+/// > // Async form (throws on failure):
+/// > func enableCredentialSharingModeWithExtendedPANId(extendedPANId: Data) async throws
 /// > ```
 /// > For information about concurrency and asynchronous code in Swift, see <doc://com.apple.documentation/documentation/swift/calling-objective-c-apis-asynchronously>.

Clone this wiki locally